#!/bin/bash

rm -rf ../out
mkdir ../out
cd ../out

$usearch -fastq_sra_splitpairs ../data/SRR3722592.fastq -mode concatenated \
  -readlength 250 -output1 fwd.fq -output2 rev.fq

$usearch -fastq_mergepairs fwd.fq -reverse rev.fq -fastqout merged.fq -relabel Merged

$usearch -fastx_truncate merged.fq -stripleft 18 -stripright 20 -fastqout stripped.fq

$usearch -fastq_filter stripped.fq -fastq_maxee 1.0 -fastaout fil.fa -relabel Fil

$usearch -fastx_uniques fil.fa -minuniquesize 2 -sizeout -fastaout uniques.fa -relabel Uniq

$usearch -cluster_otus uniques.fa -otus otus.fa -relabel Otu

$usearch -unoise3 uniques.fa -zotus zotus.fa

$usearch -uparse_ref otus.fa -db ../ref/ref.fa -strand plus -uparseout otus.up

$usearch -uparse_ref zotus.fa -db ../ref/ref.fa -strand plus -uparseout zotus.up

echo
echo ==== otus ===
cut -f2 otus.up | sort | uniq -c

echo
echo ==== zotus ===
cut -f2 zotus.up | sort | uniq -c

mkdir -p ../reads_ref
cd ../reads_ref

$usearch -usearch_global ../out/stripped.fq -db ../ref/ref.fa -id 0.97 \
  -strand both -uc hits.uc

grep "^H" hits.uc | cut -f10 | sort | uniq -c | sort -rn > reads_ref_counts.txt
grep "^H" hits.uc | grep "	100\.0	" | cut -f10 | sort | uniq -c | sort -rn > reads_ref_100_counts.txt


mkdir -p ../other
cd ../other

grep -w other ../out/otus.up | cut -f1 > labels_otus.txt
grep -w other ../out/zotus.up | cut -f1 > labels_zotus.txt

$usearch -fastx_getseqs ../out/otus.fa -labels labels_otus.txt -fastaout other_otus.fa
$usearch -fastx_getseqs ../out/zotus.fa -labels labels_zotus.txt -fastaout other_zotus.fa

$usearch -usearch_global other_otus.fa -db ../data/unite.fa -strand both -id 0.97 -uc other_otus_unite.uc
$usearch -usearch_global other_zotus.fa -db ../data/unite.fa -strand both -id 0.97 -uc other_zotus_unite.uc

rm -rf ../results
mkdir ../results

cd ../out
cp otus.fa zotus.fa otus.up zotus.up ../results

cd ../other
cp other_otus.fa other_zotus.fa other_otus_unite.uc other_zotus_unite.uc ../results

cd ../reads_ref
cp *counts.txt ../results
